#!/bin/bash

#set -x

REGEXP="$1"
SERVERS="$(nova list | grep '| Running ')" 
FSERVERS=$(awk '{print $4}' <<<"$SERVERS" | grep -E "$REGEXP") 

if [[ "$SERVERS" =~ ^\ +$ ]] || [ -z "$SERVERS" ]; then
	echo "No servers found, exit"
	echo "Do you have your openstack env set ??"
	exit 2
fi

if [[ "$FSERVERS" =~ ^\ +$ ]] || [ -z "$FSERVERS" ]; then
	echo "$FSERVERS"
	echo "No servers found with your regexp \"${REGEXP}\", exit"
	exit 2
fi

SSH_SERVERS=$(osmulti_connect.py "$REGEXP" "$SSH_ARGS" <<<"$SERVERS")

if [ -n "$VERBOSE" ]; then
	echo "############"
	echo "$SSH_SERVERS"
	echo "############"
fi

if [ -z "$SSH_SERVERS" ]; then
	echo "No way into servers '$SSH_SERVERS', exiting"
	exit 1
fi

echo "Connecting to servers '$SSH_SERVERS'"

SESSION_NAME="ssh-multi-openstack__$(tr '\n' ' ' <<<"$SSH_SERVERS" | sed -E -e 's| |-|g' -e 's|[^a-z0-9A-Z\-]|_|g')"
echo $SESSION_NAME

if [ -n "$VERBOSE" ]; then
	export VERBOSE="$VERBOSE" 
	echo "Logging to tmux window 0"
fi

if [ "$TERM" == "screen" ] && [ -n "$TMUX" ]; then
	~/bin/ssh-multi.sh "${SSH_SERVERS}"
elif [ -n "$VERBOSE" ]; then
	tmux a -t "$SESSION_NAME" || tmux new -s "$SESSION_NAME" "export SSH_ARGS=\"$SSH_ARGS\" && export VERBOSE=$VERBOSE && ~/bin/ssh-multi.sh \"${SSH_SERVERS}\""
else
	tmux a -t "$SESSION_NAME" || tmux new -s "$SESSION_NAME" "export SSH_ARGS=\"$SSH_ARGS\" && ~/bin/ssh-multi.sh \"${SSH_SERVERS}\""
fi

