#!/bin/bash
# ssh-multi
# D.Kovalov
# Based on http://linuxpixies.blogspot.jp/2011/06/tmux-copy-mode-and-how-to-control.html

# a script to ssh multiple servers over multiple tmux panes
# Use from tmux with example
# SSH_ARGS="-i ~/ssh_keys/kubernetes.pem" ~/bin/ssh-multi.sh minion@136.225.157.{81,165,141}

set -x

exit_report() {
	set +x
	if [ "$2" != "0" ]; then
		traceback 1
		echo "Exit code (rc: $2)"
		echo "Staying in tmux"
		bash --norc
	fi
}

function traceback
{
  # Hide the traceback() call.
  local -i start=$(( ${1:-0} + 1 ))
  local -i end=${#BASH_SOURCE[@]}
  local -i i=0
  local -i j=0

  echo "Traceback (last called is first):" 1>&2
  for ((i=${start}; i < ${end}; i++)); do
    j=$(( $i - 1 ))
    local function="${FUNCNAME[$i]}"
    local file="${BASH_SOURCE[$i]}"
    local line="${BASH_LINENO[$j]}"
    echo "     ${function}() in ${file}:${line}" 1>&2
  done
}

#trap 'err_report $LINENO' ERR
trap 'exit_report "$LINENO" "$?"' EXIT

set -e

starttmux() {
    if [ -z "$HOSTS" ]; then
       echo -n "Please provide of list of hosts separated by space [ENTER]: "
       read HOSTS
    else
	echo "$HOSTS"
	if [[ "$HOSTS" == *$'\n'* ]]; then
		echo "newlines in HOSTS"
		IFS=$'\n' read -a hosts -d '' <<<"$HOSTS" || true
	else
		read -a hosts <<<"$HOSTS"
	fi
	declare -p hosts
    	#local hosts=( $HOSTS )
    	echo "$hosts"
    fi

    #SSH_EXTRA_ARGS="-o BatchMode=yes -o ConnectTimeout=5"
    SSH_EXTRA_ARGS="-o ConnectTimeout=10"
    SLEEP_CMD="sleep 5"
    [ -n "$VERBOSE" ] && SLEEP_CMD="bash --norc"
    tmux new-window sh -c "ssh $SSH_ARGS $SSH_EXTRA_ARGS ${hosts[0]} || $SLEEP_CMD"
    unset hosts[0];
    for i in "${hosts[@]}"; do
	IP=$(sed -E -e "s/([^@]+@|^)([^:]+):.*/\2/" <<< "$i")
	PORT=$(sed -E -e "s/([^@]+@|^)[^:]+:([0-9]+).*/\2/" <<< "$i")
	if [ "$PORT" == "$i" ]; then
		PORT=22
	fi
        tmux split-window -h  sh -c "ssh $SSH_ARGS $SSH_EXTRA_ARGS $i || $SLEEP_CMD"
    	tmux select-layout tiled > /dev/null
    done
    tmux select-pane -t 0
    tmux set-window-option synchronize-panes on > /dev/null
    [ -z "$VERBOSE" ] || unset BASH_XTRACEFD
    set +x
}

if [[ "$*" == *$'\n'* ]]; then
	echo "newline in params, IFS is newline"
	IFS=$'\n'
fi

HOSTS="${HOSTS:-$*}"

starttmux
if [ -n "$VERBOSE" ]; then
	bash --norc
fi
