# INSTALL LRS LOCALLY

This is how to install lrs software on a local machine Ubuntu 18.04 or 20.04

## Preparation Virtual Machine

```bash
sudo apt install make gcc perl
```
Install Guest Add-ons to get higher resolution.

Set machine in network bridge mode so we can login to it.  (In VirtualBox:  Settings / Network / Adapter 1 / Attached to: Bridged adapter.  If your virtual machine is running while you change this setting, you may have to reboot it.)

## general Preparation

### Install ssh on virtual machine

First make sure openssh is installed:
```bash
sudo apt install openssh-server
```

### Setting up SSH

Assume `HOSTIP` is the virtual machine's IP address.  

Do the following from the host machine (possibly replace "lrs@" with another user name, if you do not use the "lrs" account to work on the virtual machine):

```bash
scp lrs_aiics/keys/lrs_deploy* lrs@HOSTIP:.ssh/
```

You also need a key for your own account.  If you don't already have one, use
`ssh_keygen` to generate one.  Alternatively, you could do the following to 
make the `lrs_deploy` key your default key in the virtual machine, but then 
you can't use this key to (for example) commit and push changes to Gitlab.

```bash
cd .ssh/
cp lrs_deploy id_rsa
cp lrs_deploy.pub id_rsa.pub
```

Then, let USER be the user you log in with. Let INSTALL_USER be the user used
to install user specific software.  A common case is that USER and
INSTALL_USER are both lrs or any other user on the machine.

Make sure that
```bash
ssh USER@localhost
```
does not require a password.

If it requires a password, do:
```bash
ssh-copy-id -i USER@localhost
```


### Install git

```bash
sudo apt install git
```


### Optional

After logging in make sure that
```bash
sudo ls
```
does not require a password (use "sudo visudo" to edit permissions,
add `NOPASSWD:` in the right place). That is edit the line:
```bash
%sudo   ALL=(ALL:ALL) ALL
```
to
```bash
%sudo  ALL=(ALL:ALL) NOPASSWD: ALL
```

### Calling ansible-playbook with password

If the above is considered a security risk the alternativ is to give the
password as argument to the ansible-playbook command.  (The following is an
example of how a password is specified.  Don't do this now!)

```bash
ansible-playbook -i hosts playbooks/lrs.yml -e ansible_sudo_pass=******  # Just an example
```

### Clone Needed Repo

```bash
cd ${HOME}
git clone https://gitlab.liu.se/lrs/lrs_playbooks.git
```

## Ubuntu 18.04

Then make sure that the released version of ansible is installed:
```bash
sudo apt-get update
sudo apt-get install software-properties-common
sudo apt-add-repository --yes --update ppa:ansible/ansible
sudo apt-get install ansible
```

To install the lrs software for ROS 1 (required), do:
```bash
cd lrs_playbooks
ansible-playbook -i hosts playbooks/lrs.yml -e install_user=${USER} -e hostname=localhost -e user=${USER} -e ansible_sudo_pass=******
```

If you want to install the lrs software for ROS 2, do:
```bash
cd lrs_playbooks
ansible-playbook -i hosts playbooks/lrsros2.yml -e install_user=${USER} -e hostname=localhost -e user=${USER} -e ansible_sudo_pass=******
```

## Ubuntu 20.04

Install ansible:
```bash
sudo apt-get install ansible
```

To install the lrs software for ROS 1 (required), do:
```bash
cd lrs_playbooks
ansible-playbook -i hosts playbooks/lrs_20.04.yml -e install_user=${USER} -e hostname=localhost -e user=${USER} -e ansible_sudo_pass=****** [-e vpnhostname=VPNHOSTNAME]
```

If you want to install the lrs software for ROS 2, do:
```bash
cd lrs_playbooks
ansible-playbook -i hosts playbooks/lrsros2.yml -e install_user=${USER} -e hostname=localhost -e user=${USER} -e ansible_sudo_pass=******
```


## Finishing Up

If you do not set lrs_deploy as the default key than the following are useful:
```bash
GIT_SSH_COMMAND='ssh -i ~/.ssh/lrs_deploy -o IdentitiesOnly=yes' git clone repo
GIT_SSH_COMMAND='ssh -i ~/.ssh/lrs_deploy -o IdentitiesOnly=yes' git pull
GIT_SSH_COMMAND='ssh -i ~/.ssh/lrs_deploy -o IdentitiesOnly=yes' vcs-pull
```

Add the following to your .bashrc file (maybe not all is necessary...):
```bash
export WORLD_ORIGIN_LAT=57.7605573519 
export WORLD_ORIGIN_LON=16.6827607783
export WORLD_ORIGIN_ELEVATION=29.8

export PYTHONPATH=${HOME}/github/xdot.py:${PYTHONPATH}
export PATH=$PATH:/opt/eclipse_6.1_229/bin/x86_64_linux

export GECODEHOME=/opt/gecode-6.0.1
export PATH=${GECODEHOME}/bin:$PATH
export LD_LIBRARY_PATH=${GECODEHOME}/lib:$LD_LIBRARY_PATH

export LD_LIBRARY_PATH=/opt/zeromq-4.1.4/lib:$LD_LIBRARY_PATH
export LD_LIBRARY_PATH=/opt/czmq-3.0.2/lib:$LD_LIBRARY_PATH
export LD_LIBRARY_PATH=/opt/zyre-1.1.0/lib:$LD_LIBRARY_PATH

bind '"\e[A"':history-search-backward
bind '"\e[B"':history-search-forward
bind '"\ep"':history-search-backward
bind '"\en"':history-search-forward

export LRS_LOCATION=granso
#export ZSYS_INTERFACE=wlp2s0

source /home/${USER}/pkg/lrs-pkg/lrs-pkg/shells/config.bash
```

For 18.04 add:
```bash
source /opt/ros/melodic/setup.bash
source ${HOME}/lrs_ws/devel/setup.bash

ros1setup() {
  unset ROS_PACKAGE_PATH
  source /opt/ros/noetic/setup.bash  
  source ${HOME}/lrs_ws/devel/setup.bash
  source `rospack find lrs_common`/lrssetup.bash  
}

ros2setup() {
  unset ROS_PACKAGE_PATH
  source /opt/ros/dashing/setup.bash
  source /opt/ros2/lrs2_ws/install/local_setup.bash
}
```

For 20.04 add:
```bash
source /opt/ros/noetic/setup.bash
source ${HOME}/lrs_ws/devel/setup.bash

ros1setup() {
  unset ROS_PACKAGE_PATH
  source /opt/ros/noetic/setup.bash  
  source ${HOME}/lrs_ws/devel/setup.bash
  source `rospack find lrs_common`/lrssetup.bash  
}

ros2setup() {
  unset ROS_PACKAGE_PATH
  source /opt/ros/foxy/setup.bash
  source /opt/ros2/lrs2_ws/install/setup.bash
}
```
